// Copyright 2020 Google LLC All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// This code was autogenerated. Do not edit directly.

// Code generated by client-gen. DO NOT EDIT.

package fake

import (
	"context"

	agonesv1 "agones.dev/agones/pkg/apis/agones/v1"
	autoscalingv1 "k8s.io/api/autoscaling/v1"
	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	labels "k8s.io/apimachinery/pkg/labels"
	schema "k8s.io/apimachinery/pkg/runtime/schema"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	testing "k8s.io/client-go/testing"
)

// FakeGameServerSets implements GameServerSetInterface
type FakeGameServerSets struct {
	Fake *FakeAgonesV1
	ns   string
}

var gameserversetsResource = schema.GroupVersionResource{Group: "agones.dev", Version: "v1", Resource: "gameserversets"}

var gameserversetsKind = schema.GroupVersionKind{Group: "agones.dev", Version: "v1", Kind: "GameServerSet"}

// Get takes name of the gameServerSet, and returns the corresponding gameServerSet object, and an error if there is any.
func (c *FakeGameServerSets) Get(ctx context.Context, name string, options v1.GetOptions) (result *agonesv1.GameServerSet, err error) {
	obj, err := c.Fake.
		Invokes(testing.NewGetAction(gameserversetsResource, c.ns, name), &agonesv1.GameServerSet{})

	if obj == nil {
		return nil, err
	}
	return obj.(*agonesv1.GameServerSet), err
}

// List takes label and field selectors, and returns the list of GameServerSets that match those selectors.
func (c *FakeGameServerSets) List(ctx context.Context, opts v1.ListOptions) (result *agonesv1.GameServerSetList, err error) {
	obj, err := c.Fake.
		Invokes(testing.NewListAction(gameserversetsResource, gameserversetsKind, c.ns, opts), &agonesv1.GameServerSetList{})

	if obj == nil {
		return nil, err
	}

	label, _, _ := testing.ExtractFromListOptions(opts)
	if label == nil {
		label = labels.Everything()
	}
	list := &agonesv1.GameServerSetList{ListMeta: obj.(*agonesv1.GameServerSetList).ListMeta}
	for _, item := range obj.(*agonesv1.GameServerSetList).Items {
		if label.Matches(labels.Set(item.Labels)) {
			list.Items = append(list.Items, item)
		}
	}
	return list, err
}

// Watch returns a watch.Interface that watches the requested gameServerSets.
func (c *FakeGameServerSets) Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error) {
	return c.Fake.
		InvokesWatch(testing.NewWatchAction(gameserversetsResource, c.ns, opts))

}

// Create takes the representation of a gameServerSet and creates it.  Returns the server's representation of the gameServerSet, and an error, if there is any.
func (c *FakeGameServerSets) Create(ctx context.Context, gameServerSet *agonesv1.GameServerSet, opts v1.CreateOptions) (result *agonesv1.GameServerSet, err error) {
	obj, err := c.Fake.
		Invokes(testing.NewCreateAction(gameserversetsResource, c.ns, gameServerSet), &agonesv1.GameServerSet{})

	if obj == nil {
		return nil, err
	}
	return obj.(*agonesv1.GameServerSet), err
}

// Update takes the representation of a gameServerSet and updates it. Returns the server's representation of the gameServerSet, and an error, if there is any.
func (c *FakeGameServerSets) Update(ctx context.Context, gameServerSet *agonesv1.GameServerSet, opts v1.UpdateOptions) (result *agonesv1.GameServerSet, err error) {
	obj, err := c.Fake.
		Invokes(testing.NewUpdateAction(gameserversetsResource, c.ns, gameServerSet), &agonesv1.GameServerSet{})

	if obj == nil {
		return nil, err
	}
	return obj.(*agonesv1.GameServerSet), err
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
func (c *FakeGameServerSets) UpdateStatus(ctx context.Context, gameServerSet *agonesv1.GameServerSet, opts v1.UpdateOptions) (*agonesv1.GameServerSet, error) {
	obj, err := c.Fake.
		Invokes(testing.NewUpdateSubresourceAction(gameserversetsResource, "status", c.ns, gameServerSet), &agonesv1.GameServerSet{})

	if obj == nil {
		return nil, err
	}
	return obj.(*agonesv1.GameServerSet), err
}

// Delete takes name of the gameServerSet and deletes it. Returns an error if one occurs.
func (c *FakeGameServerSets) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error {
	_, err := c.Fake.
		Invokes(testing.NewDeleteAction(gameserversetsResource, c.ns, name), &agonesv1.GameServerSet{})

	return err
}

// DeleteCollection deletes a collection of objects.
func (c *FakeGameServerSets) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error {
	action := testing.NewDeleteCollectionAction(gameserversetsResource, c.ns, listOpts)

	_, err := c.Fake.Invokes(action, &agonesv1.GameServerSetList{})
	return err
}

// Patch applies the patch and returns the patched gameServerSet.
func (c *FakeGameServerSets) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *agonesv1.GameServerSet, err error) {
	obj, err := c.Fake.
		Invokes(testing.NewPatchSubresourceAction(gameserversetsResource, c.ns, name, pt, data, subresources...), &agonesv1.GameServerSet{})

	if obj == nil {
		return nil, err
	}
	return obj.(*agonesv1.GameServerSet), err
}

// GetScale takes name of the gameServerSet, and returns the corresponding scale object, and an error if there is any.
func (c *FakeGameServerSets) GetScale(ctx context.Context, gameServerSetName string, options v1.GetOptions) (result *autoscalingv1.Scale, err error) {
	obj, err := c.Fake.
		Invokes(testing.NewGetSubresourceAction(gameserversetsResource, c.ns, "scale", gameServerSetName), &autoscalingv1.Scale{})

	if obj == nil {
		return nil, err
	}
	return obj.(*autoscalingv1.Scale), err
}

// UpdateScale takes the representation of a scale and updates it. Returns the server's representation of the scale, and an error, if there is any.
func (c *FakeGameServerSets) UpdateScale(ctx context.Context, gameServerSetName string, scale *autoscalingv1.Scale, opts v1.UpdateOptions) (result *autoscalingv1.Scale, err error) {
	obj, err := c.Fake.
		Invokes(testing.NewUpdateSubresourceAction(gameserversetsResource, "scale", c.ns, scale), &autoscalingv1.Scale{})

	if obj == nil {
		return nil, err
	}
	return obj.(*autoscalingv1.Scale), err
}
